@@ -78,6 +78,7 @@ typedef short bp_int16;
 #define DHCP_OPTION_OPTIONREQ		55
 #define DHCP_OPTION_MAXSIZE		57
 #define DHCP_OPTION_T1			58
+#define DHCP_OPTION_CLASS_IDENTIFIER    60
 #define DHCP_OPTION_CLIENT_IDENTIFIER	61
 
 #define BOOTP_CLIENT_PORT	68
@@ -142,7 +143,7 @@ static char * getInterfaceInfo(struct pumpNetIntf * intf, int s);
 static char * perrorstr(char * msg);
 static void addClientIdentifier(int flags, struct bootpRequest * req);
 static void buildRequest(struct bootpRequest * req, int flags, int type,
-		         char * reqHostname, int lease);
+		         char * reqHostname, char *class, int lease);
 static void updateSecCount(struct bootpRequest * breq, time_t startTime);
 
 static const char vendCookie[] = { 99, 130, 83, 99, 255 };
@@ -235,8 +236,6 @@ char * pumpSetupInterface(struct pumpNetIntf * intf) {
     struct rtentry route;
     int s;
 
-    if ((rc = pumpDisableInterface(intf->device))) return rc;
-
     s = socket(AF_INET, SOCK_DGRAM, 0);
 	
     memset(&req,0,sizeof(req));
@@ -1178,7 +1177,7 @@ static void addClientIdentifier(int flags, struct bootpRequest * req) {
 }
 
 static void buildRequest(struct bootpRequest * req, int flags, int type,
-		         char * reqHostname, int lease) {
+		         char * reqHostname, char *class, int lease) {
     unsigned char messageType = type;
     short aShort;
     int anInt;
@@ -1222,14 +1221,17 @@ static void buildRequest(struct bootpRequest * req, int flags, int type,
 	addVendorCode(req, BOOTP_OPTION_HOSTNAME,
 		      strlen(reqHostname) + 1, reqHostname);
     }
-
+    if (class) {
+       addVendorCode(req, DHCP_OPTION_CLASS_IDENTIFIER,
+                     strlen(class) + 1, class);
+    }
     anInt = htonl(lease);
     addVendorCode(req, DHCP_OPTION_LEASE, 4, &anInt);
 }
 
-char * pumpDhcpRun(char * device, int flags, int reqLease,
-		   char * reqHostname, struct pumpNetIntf * intf,
-		   struct pumpOverrideInfo * override) {
+char * pumpDhcpClassRun(char * device, int flags, int reqLease,
+                  char * reqHostname, char * class, struct pumpNetIntf * intf,
+		  struct pumpOverrideInfo * override) {
     int s;
     struct sockaddr_in serverAddr;
     struct sockaddr_in clientAddr;
@@ -1291,7 +1293,11 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
 	addVendorCode(&breq, BOOTP_OPTION_HOSTNAME,
 		      strlen(reqHostname) + 1, reqHostname);
     }
-
+    if (class) {
+       syslog(LOG_DEBUG, "CLASSID: sending %s\n", class);
+        addVendorCode(&breq, DHCP_OPTION_CLASS_IDENTIFIER,
+                      strlen(class) + 1, class);
+    }
     memset(&clientAddr.sin_addr, 0, sizeof(&clientAddr.sin_addr));
     clientAddr.sin_family = AF_INET;
     clientAddr.sin_port = htons(BOOTP_CLIENT_PORT);	/* bootp client */
@@ -1345,7 +1351,7 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
 	syslog (LOG_DEBUG, "got dhcp offer\n");
 
 	initVendorCodes(&breq);
-	buildRequest(&breq, flags, DHCP_TYPE_DISCOVER, reqHostname, 
+	buildRequest(&breq, flags, DHCP_TYPE_DISCOVER, reqHostname, class,
 		     intf->reqLease);
 
 	syslog (LOG_DEBUG, "PUMP: sending second discover");
@@ -1374,7 +1380,7 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
 	}
 
 	initVendorCodes(&breq);
-	buildRequest(&breq, flags, DHCP_TYPE_REQUEST, reqHostname, 
+	buildRequest(&breq, flags, DHCP_TYPE_REQUEST, reqHostname, class,
 		     intf->reqLease);
 
 	addVendorCode(&breq, DHCP_OPTION_SERVER, 4, &serverAddr.sin_addr);
@@ -1414,6 +1420,13 @@ char * pumpDhcpRun(char * device, int flags, int reqLease,
     return NULL;
 }
 
+char * pumpDhcpRun(char * device, int flags, int reqLease,
+                  char * reqHostname, struct pumpNetIntf * intf,
+                  struct pumpOverrideInfo * override) {
+    pumpDhcpClassRun(device, flags, reqLease, reqHostname, NULL, intf,
+                     override);
+}
+
 void pumpInitOverride(struct pumpOverrideInfo * override) {
     strcpy(override->intf.device, "MASTER");
     override->timeout = DEFAULT_TIMEOUT;
